==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetEnvironments.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEnvironments] (
	@VCC Varchar(50) = NULL, 
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL,
	@IncludeAllegro Bit = 1
	)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[Name]					'name',
		[Type]					'type',
		[Description]			'description',
		[FTPDirectory]			'ftpDirectory',
		[ApiHost]				'apiHost',
		[ApiPort]				'apiPort',
		[ApiUser]				'apiUser',
		[DbDisabled]			'dbDisabled',
		[DbServer]				'dbServer',
		[DbPort]				'dbPort',
		[DbUser]				'dbUser',
		[PbxDisabled]			'pbxDisabled',
		[PbxServer]			    'pbxServer',
		[PbxPort]			    'pbxPort',
		[PbxUser]			    'pbxUser',
		[CreatedDate]			'createdDate',
		[CreatedByUserId]		'createdByUserId',
		[LastModifiedDate]		'lastModifiedDate',
		[LastModifiedByUserId]	'lastModifiedByUserId'
	FROM [Environment] (NOLOCK)
	WHERE [VCC] = @VCC
		AND [Type] NOT LIKE CASE WHEN @IncludeAllegro = 0 THEN '%allegro%' ELSE '' END
		AND ISNULL([Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL([ApiHost], '') LIKE CASE WHEN @SearchCriteria = 'host' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL([Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetEnvironments.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEnvironments] (
	@VCC Varchar(50) = NULL, 
	@SearchCriteria Varchar(50) = NULL, 
	@SearchExpression Varchar(50) = NULL,
	@IncludeIntegrated Bit = 1
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT
		[Name]					'name',
		[Type]					'type',
		[Description]			'description',
		[FTPDirectory]			'ftpDirectory',
		[ApiHost]				'apiHost',
		[ApiPort]				'apiPort',
		[ApiUser]				'apiUser',
		[DbDisabled]			'dbDisabled',
		[DbServer]				'dbServer',
		[DbPort]				'dbPort',
		[DbUser]				'dbUser',
		[PbxDisabled]			'pbxDisabled',
		[PbxServer]			    'pbxServer',
		[PbxPort]			    'pbxPort',
		[PbxUser]			    'pbxUser',
		[CreatedDate]			'createdDate',
		[CreatedByUserId]		'createdByUserId',
		[LastModifiedDate]		'lastModifiedDate',
		[LastModifiedByUserId]	'lastModifiedByUserId'
	FROM [Environment] (NOLOCK)
	WHERE [VCC] = @VCC
		--AND [Type] NOT LIKE CASE WHEN @IncludeIntegrated = 0 THEN '%allegro%' ELSE '' END
		AND (
			(
				@IncludeIntegrated = 0
				AND
				[Type] NOT IN ('allegro', 'i6')
			)
			OR 
			@IncludeIntegrated = 1
		)
		AND ISNULL([Name], '') LIKE CASE WHEN @SearchCriteria = 'name' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL([Description], '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL([ApiHost], '') LIKE CASE WHEN @SearchCriteria = 'host' THEN '%' + @SearchExpression + '%' ELSE '%' END
		AND ISNULL([Type], '') LIKE CASE WHEN @SearchCriteria = 'type' THEN '%' + @SearchExpression + '%' ELSE '%' END
		
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
